@@ -1,14 +1,20 @@
-import random
+"""Module for Cage-like time brackets.
+
+Time brackets are events which are defined by unspecified start and end times.
+"""
+
 import typing
 
 from mutwo.events import basic
-from mutwo.events import music
+from mutwo.events import brackets
 from mutwo.utilities import constants
-from mutwo.parameters import tempos
+from mutwo.utilities import exceptions
+
+__all__ = (
+    "TimeBracket",
+    "TimeBracketContainer",
+)
 
-from ot2.events import basic as ot2_basic
-from ot2.events import brackets
-from ot2.utilities import exceptions
 
 TimeOrTimeRange = typing.Union[
     constants.Real, typing.Tuple[constants.Real, constants.Real]
@@ -18,18 +24,30 @@ TimeOrTimeRange = typing.Union[
 class TimeBracket(brackets.Bracket):
     def __init__(
         self,
-        simultaneous_events: typing.Sequence[
-            ot2_basic.AssignedSimultaneousEvent[basic.SequentialEvent[music.NoteLike]]
+        tagged_events: typing.Sequence[
+            typing.Union[
+                basic.TaggedSimpleEvent,
+                basic.TaggedSequentialEvent,
+                basic.TaggedSimultaneousEvent,
+            ]
         ],
         start_or_start_range: TimeOrTimeRange,
         end_or_end_range: TimeOrTimeRange,
+        seed: typing.Optional[int] = None,
     ):
-        super().__init__(simultaneous_events, start_or_start_range, end_or_end_range)
+        super().__init__(tagged_events, start_or_start_range, end_or_end_range)
 
-    @staticmethod
-    def _assign_concrete_time(time_or_time_range: TimeOrTimeRange) -> constants.Real:
+        import random as time_bracket_random
+
+        if seed:
+            time_bracket_random.seed(seed)
+        self._time_bracket_random = time_bracket_random
+
+    def _assign_concrete_time(
+        self, time_or_time_range: TimeOrTimeRange
+    ) -> constants.Real:
         if hasattr(time_or_time_range, "__getitem__"):
-            return random.uniform(*time_or_time_range)
+            return self._time_bracket_random.uniform(*time_or_time_range)
         else:
             return time_or_time_range
 
@@ -75,38 +93,11 @@ class TimeBracket(brackets.Bracket):
 
     def assign_concrete_times(self):
         """Assign concrete values for start and end time"""
-        self._assigned_start_time = TimeBracket._assign_concrete_time(
+
+        self._assigned_start_time = self._assign_concrete_time(
             self.start_or_start_range
         )
-        self._assigned_end_time = TimeBracket._assign_concrete_time(
-            self.end_or_end_range
-        )
-
-
-class TempoBasedTimeBracket(TimeBracket):
-    def __init__(
-        self,
-        sequential_events: typing.Sequence[basic.SequentialEvent],
-        start_time_range: typing.Tuple[constants.Real, constants.Real],
-        tempo_range: typing.Tuple[tempos.TempoPoint, tempos.TempoPoint],
-    ):
-        self._tempo_range = tempo_range
-        end_time_range = TempoBasedTimeBracket._find_end_time_range(
-            sequential_events, start_time_range, tempo_range
-        )
-        super().__init__(sequential_events, start_time_range, end_time_range)
-
-    @staticmethod
-    def _find_end_time_range(
-        sequential_events: typing.Sequence[basic.SequentialEvent],
-        start_time_range: typing.Tuple[constants.Real, constants.Real],
-        tempo_range: typing.Tuple[tempos.TempoPoint, tempos.TempoPoint],
-    ) -> typing.Tuple[constants.Real, constants.Real]:
-        pass
-
-    @property
-    def tempo_range(self) -> typing.Tuple[tempos.TempoPoint, tempos.TempoPoint]:
-        return self._tempo_range
+        self._assigned_end_time = self._assign_concrete_time(self.end_or_end_range)
 
 
 class TimeBracketContainer(brackets.BracketContainer[TimeBracket]):
